==> drools-model-compiler-0.3.0-sources.jar: org/drools/modelcompiler/builder/ModelWriter.java <==
package org.drools.modelcompiler.builder;

import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.stream.Collectors;

import org.drools.compiler.compiler.io.memory.MemoryFileSystem;
import org.drools.core.util.Drools;
import org.kie.api.builder.ReleaseId;

import static org.drools.modelcompiler.CanonicalKieModule.MODEL_VERSION;
import static org.drools.modelcompiler.CanonicalKieModule.getModelFileWithGAV;
import static org.drools.modelcompiler.builder.PackageModel.DOMAIN_CLASSESS_METADATA_FILE_NAME;

public class ModelWriter {

    public static final String CDI_ANNOTATION = "@javax.enterprise.context.ApplicationScoped";

    private final String basePath;

    public ModelWriter() {
        this("src/main/java");
    }

    public ModelWriter(String basePath) {
        this.basePath = basePath;
    }

    public Result writeModel(MemoryFileSystem srcMfs, Collection<PackageModel> packageModels, boolean oneClassPerRule) {
        List<GeneratedFile> generatedFiles = new ArrayList<>();
        List<String> modelFiles = new ArrayList<>();

        for (PackageModel pkgModel : packageModels) {
            PackageModelWriter packageModelWriter = new PackageModelWriter(pkgModel, oneClassPerRule);
            for (DeclaredTypeWriter declaredType : packageModelWriter.getDeclaredTypes()) {
                generatedFiles.add(new GeneratedFile(declaredType.getName(), declaredType.getSource()));
            }

            for (AccumulateClassWriter accumulateClassWriter : packageModelWriter.getAccumulateClasses()) {
                generatedFiles.add(new GeneratedFile(accumulateClassWriter.getName(), accumulateClassWriter.getSource()));
            }

            RuleWriter rules = packageModelWriter.getRules();
            generatedFiles.add(new GeneratedFile(rules.getName(), rules.getMainSource()));
            modelFiles.addAll( rules.getModels() );

            for (RuleWriter.RuleFileSource ruleSource : rules.getRuleSources()) {
                generatedFiles.add(new GeneratedFile(ruleSource.getName(), ruleSource.getSource()));
            }

            PackageModelWriter.DomainClassesMetadata domainClassesMetadata = packageModelWriter.getDomainClassesMetadata();
            generatedFiles.add(new GeneratedFile(domainClassesMetadata.getName(), domainClassesMetadata.getSource()));
        }

        List<String> sourceFiles = new ArrayList<>();
        for (GeneratedFile generatedFile : generatedFiles) {
            String path = basePath + "/" + generatedFile.getPath();
            sourceFiles.add(path);
            srcMfs.write(path, generatedFile.getData());
        }

        return new Result(sourceFiles, modelFiles);
    }

    private String pojoName(String folderName, String nameAsString) {
        return basePath + "/" + folderName + "/" + nameAsString + ".java";
    }

    public void writeModelFile(Collection<String> modelSources, MemoryFileSystem trgMfs, ReleaseId releaseId) {
        String pkgNames = MODEL_VERSION + Drools.getFullVersion() + "\n";
        if (!modelSources.isEmpty()) {
            pkgNames += modelSources.stream().collect(Collectors.joining("\n"));
        }
        trgMfs.write(getModelFileWithGAV(releaseId), pkgNames.getBytes());
    }

    private static class GeneratedFile {

        final String path;
        final byte[] data;

        private GeneratedFile(String path, String data) {
            this.path = path;
            this.data = data.getBytes(StandardCharsets.UTF_8);
        }

        private GeneratedFile(String path, byte[] data) {
            this.path = path;
            this.data = data;
        }

        public byte[] getData() {
            return data;
        }

        public String getPath() {
            return path;
        }

        @Override
        public String toString() {
            return "GeneratedFile{" +
                    "path='" + path + '\'' +
                    '}';
        }
    }

    public static class Result {

        private final List<String> sourceFiles;
        private final List<String> modelFiles;

        public Result(List<String> sourceFiles, List<String> modelFiles) {
            this.sourceFiles = sourceFiles;
            this.modelFiles = modelFiles;
        }

        public List<String> getSources() {
            return sourceFiles;
        }

        public List<String> getSourceFiles() {
            return sourceFiles;
        }

        public List<String> getModelFiles() {
            return modelFiles;
        }
    }
}

==> drools-model-compiler-0.5.0-sources.jar: org/drools/modelcompiler/builder/ModelWriter.java <==
package org.drools.modelcompiler.builder;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.stream.Collectors;

import org.drools.compiler.compiler.io.memory.MemoryFileSystem;
import org.drools.core.util.Drools;
import org.kie.api.builder.ReleaseId;

import static org.drools.modelcompiler.CanonicalKieModule.MODEL_VERSION;
import static org.drools.modelcompiler.CanonicalKieModule.getModelFileWithGAV;

public class ModelWriter {

    public static final String CDI_ANNOTATION = "@javax.enterprise.context.ApplicationScoped";

    private final String basePath;

    public ModelWriter() {
        this("src/main/java");
    }

    public ModelWriter(String basePath) {
        this.basePath = basePath;
    }

    public Result writeModel(MemoryFileSystem srcMfs, MemoryFileSystem trgMfs, Collection<PackageSources> packageSources) {
        List<GeneratedFile> generatedFiles = new ArrayList<>();
        List<String> modelFiles = new ArrayList<>();

        for (PackageSources pkgSources : packageSources) {
            generatedFiles.addAll( pkgSources.getPojoSources() );
            generatedFiles.addAll( pkgSources.getAccumulateSources() );
            generatedFiles.add( pkgSources.getMainSource() );
            generatedFiles.addAll( pkgSources.getRuleSources() );
            generatedFiles.add( pkgSources.getDomainClassSource() );
            modelFiles.addAll( pkgSources.getModelNames() );

            if (pkgSources.getReflectConfigSource() != null) {
                trgMfs.write( pkgSources.getReflectConfigSource().getPath(), pkgSources.getReflectConfigSource().getData() );
            }
        }

        List<String> sourceFiles = new ArrayList<>();
        for (GeneratedFile generatedFile : generatedFiles) {
            String path = basePath + "/" + generatedFile.getPath();
            sourceFiles.add(path);
            srcMfs.write(path, generatedFile.getData());
        }

        return new Result(sourceFiles, modelFiles);
    }

    private String pojoName(String folderName, String nameAsString) {
        return basePath + "/" + folderName + "/" + nameAsString + ".java";
    }

    public void writeModelFile(Collection<String> modelSources, MemoryFileSystem trgMfs, ReleaseId releaseId) {
        String pkgNames = MODEL_VERSION + Drools.getFullVersion() + "\n";
        if (!modelSources.isEmpty()) {
            pkgNames += modelSources.stream().collect(Collectors.joining("\n"));
        }
        trgMfs.write(getModelFileWithGAV(releaseId), pkgNames.getBytes());
    }

    public static class Result {

        private final List<String> sourceFiles;
        private final List<String> modelFiles;

        public Result(List<String> sourceFiles, List<String> modelFiles) {
            this.sourceFiles = sourceFiles;
            this.modelFiles = modelFiles;
        }

        public List<String> getSources() {
            return sourceFiles;
        }

        public List<String> getSourceFiles() {
            return sourceFiles;
        }

        public List<String> getModelFiles() {
            return modelFiles;
        }
    }
}
